You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by rh...@apache.org on 2011/05/02 21:23:52 UTC

svn commit: r1098756 - in /subversion/trunk/subversion: libsvn_client/commit_util.c libsvn_client/externals.c libsvn_repos/rev_hunt.c svn/update-cmd.c

Author: rhuijben
Date: Mon May  2 19:23:51 2011
New Revision: 1098756

URL: http://svn.apache.org/viewvc?rev=1098756&view=rev
Log:
Rename some 'iter_pool' variables to 'iterpool' to make sure I keep following
the convention.

* subversion/libsvn_client/commit_util.c
  (svn_client__do_commit): Rename variable.

* subversion/libsvn_client/externals.c
  (handle_external_item_change_baton): Rename variable.
  (handle_external_item_change,
   handle_externals_desc_change): Update users.

* subversion/libsvn_repos/rev_hunt.c
  (send_baton): Rename variable.
  (send_path_revision): Update user.
  (svn_repos_get_file_revs2): Update caller.

* subversion/svn/update-cmd.c
  (print_update_summary): Rename variable.

Modified:
    subversion/trunk/subversion/libsvn_client/commit_util.c
    subversion/trunk/subversion/libsvn_client/externals.c
    subversion/trunk/subversion/libsvn_repos/rev_hunt.c
    subversion/trunk/subversion/svn/update-cmd.c

Modified: subversion/trunk/subversion/libsvn_client/commit_util.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/commit_util.c?rev=1098756&r1=1098755&r2=1098756&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/commit_util.c (original)
+++ subversion/trunk/subversion/libsvn_client/commit_util.c Mon May  2 19:23:51 2011
@@ -1469,7 +1469,7 @@ svn_client__do_commit(const char *base_u
 {
   apr_hash_t *file_mods = apr_hash_make(scratch_pool);
   apr_hash_t *items_hash = apr_hash_make(scratch_pool);
-  apr_pool_t *iter_pool = svn_pool_create(scratch_pool);
+  apr_pool_t *iterpool = svn_pool_create(scratch_pool);
   apr_hash_index_t *hi;
   int i;
   struct path_driver_cb_baton cb_baton;
@@ -1526,7 +1526,7 @@ svn_client__do_commit(const char *base_u
       const svn_checksum_t *new_text_base_sha1_checksum;
       svn_boolean_t fulltext = FALSE;
 
-      svn_pool_clear(iter_pool);
+      svn_pool_clear(iterpool);
 
       /* Transmit the entry. */
       if (ctx->cancel_func)
@@ -1537,10 +1537,10 @@ svn_client__do_commit(const char *base_u
           svn_wc_notify_t *notify;
           notify = svn_wc_create_notify(item->path,
                                         svn_wc_notify_commit_postfix_txdelta,
-                                        iter_pool);
+                                        iterpool);
           notify->kind = svn_node_file;
           notify->path_prefix = notify_path_prefix;
-          ctx->notify_func2(ctx->notify_baton2, notify, iter_pool);
+          ctx->notify_func2(ctx->notify_baton2, notify, iterpool);
         }
 
       /* If the node has no history, transmit full text */
@@ -1552,7 +1552,7 @@ svn_client__do_commit(const char *base_u
                                            &new_text_base_sha1_checksum,
                                            ctx->wc_ctx, item->path,
                                            fulltext, editor, mod->file_baton,
-                                           result_pool, iter_pool));
+                                           result_pool, iterpool));
       if (md5_checksums)
         apr_hash_set(*md5_checksums, item->path, APR_HASH_KEY_STRING,
                      new_text_base_md5_checksum);
@@ -1561,7 +1561,7 @@ svn_client__do_commit(const char *base_u
                      new_text_base_sha1_checksum);
     }
 
-  svn_pool_destroy(iter_pool);
+  svn_pool_destroy(iterpool);
 
   /* Close the edit. */
   return editor->close_edit(edit_baton, scratch_pool);

Modified: subversion/trunk/subversion/libsvn_client/externals.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/externals.c?rev=1098756&r1=1098755&r2=1098756&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_repos/rev_hunt.c (original)
+++ subversion/trunk/subversion/libsvn_repos/rev_hunt.c Mon May  2 19:23:51 2011
@@ -1339,7 +1339,7 @@ find_merged_revisions(apr_array_header_t
 
 struct send_baton
 {
-  apr_pool_t *iter_pool;
+  apr_pool_t *iterpool;
   apr_pool_t *last_pool;
   apr_hash_t *last_props;
   const char *last_path;
@@ -1365,28 +1365,28 @@ send_path_revision(struct path_revision 
   apr_pool_t *tmp_pool;  /* For swapping */
   svn_boolean_t contents_changed;
 
-  svn_pool_clear(sb->iter_pool);
+  svn_pool_clear(sb->iterpool);
 
   /* Get the revision properties. */
   SVN_ERR(svn_fs_revision_proplist(&rev_props, repos->fs,
-                                   path_rev->revnum, sb->iter_pool));
+                                   path_rev->revnum, sb->iterpool));
 
   /* Open the revision root. */
   SVN_ERR(svn_fs_revision_root(&root, repos->fs, path_rev->revnum,
-                               sb->iter_pool));
+                               sb->iterpool));
 
   /* Get the file's properties for this revision and compute the diffs. */
   SVN_ERR(svn_fs_node_proplist(&props, root, path_rev->path,
-                                   sb->iter_pool));
+                                   sb->iterpool));
   SVN_ERR(svn_prop_diffs(&prop_diffs, props, sb->last_props,
-                         sb->iter_pool));
+                         sb->iterpool));
 
   /* Check if the contents changed. */
   /* Special case: In the first revision, we always provide a delta. */
   if (sb->last_root)
     SVN_ERR(svn_fs_contents_changed(&contents_changed, sb->last_root,
                                     sb->last_path, root, path_rev->path,
-                                    sb->iter_pool));
+                                    sb->iterpool));
   else
     contents_changed = TRUE;
 
@@ -1395,7 +1395,7 @@ send_path_revision(struct path_revision 
                   rev_props, path_rev->merged,
                   contents_changed ? &delta_handler : NULL,
                   contents_changed ? &delta_baton : NULL,
-                  prop_diffs, sb->iter_pool));
+                  prop_diffs, sb->iterpool));
 
   /* Compute and send delta if client asked for it.
      Note that this was initialized to NULL, so if !contents_changed,
@@ -1406,11 +1406,11 @@ send_path_revision(struct path_revision 
       SVN_ERR(svn_fs_get_file_delta_stream(&delta_stream,
                                            sb->last_root, sb->last_path,
                                            root, path_rev->path,
-                                           sb->iter_pool));
+                                           sb->iterpool));
       /* And send. */
       SVN_ERR(svn_txdelta_send_txstream(delta_stream,
                                         delta_handler, delta_baton,
-                                        sb->iter_pool));
+                                        sb->iterpool));
     }
 
   /* Remember root, path and props for next iteration. */
@@ -1419,8 +1419,8 @@ send_path_revision(struct path_revision 
   sb->last_props = props;
 
   /* Swap the pools. */
-  tmp_pool = sb->iter_pool;
-  sb->iter_pool = sb->last_pool;
+  tmp_pool = sb->iterpool;
+  sb->iterpool = sb->last_pool;
   sb->last_pool = tmp_pool;
 
   return SVN_NO_ERROR;
@@ -1485,7 +1485,7 @@ svn_repos_get_file_revs2(svn_repos_t *re
 
   /* We switch betwwen two pools while looping, since we need information from
      the last iteration to be available. */
-  sb.iter_pool = svn_pool_create(pool);
+  sb.iterpool = svn_pool_create(pool);
   sb.last_pool = svn_pool_create(pool);
 
   /* We want the first txdelta to be against the empty file. */
@@ -1542,7 +1542,7 @@ svn_repos_get_file_revs2(svn_repos_t *re
     }
 
   svn_pool_destroy(sb.last_pool);
-  svn_pool_destroy(sb.iter_pool);
+  svn_pool_destroy(sb.iterpool);
 
   return SVN_NO_ERROR;
 }

Modified: subversion/trunk/subversion/svn/update-cmd.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/update-cmd.c?rev=1098756&r1=1098755&r2=1098756&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/update-cmd.c (original)
+++ subversion/trunk/subversion/svn/update-cmd.c Mon May  2 19:23:51 2011
@@ -50,7 +50,7 @@ print_update_summary(apr_array_header_t 
 {
   int i;
   const char *path_prefix;
-  apr_pool_t *iter_pool;
+  apr_pool_t *iterpool;
 
   if (targets->nelts < 2)
     return SVN_NO_ERROR;
@@ -58,14 +58,14 @@ print_update_summary(apr_array_header_t 
   SVN_ERR(svn_dirent_get_absolute(&path_prefix, "", scratch_pool));
   SVN_ERR(svn_cmdline_printf(scratch_pool, _("Summary of updates:\n")));
 
-  iter_pool = svn_pool_create(scratch_pool);
+  iterpool = svn_pool_create(scratch_pool);
 
   for (i = 0; i < targets->nelts; i++)
     {
       const char *path = APR_ARRAY_IDX(targets, i, const char *);
       svn_revnum_t rev = SVN_INVALID_REVNUM;
 
-      svn_pool_clear(iter_pool);
+      svn_pool_clear(iterpool);
 
       /* PATH shouldn't be a URL. */
       SVN_ERR_ASSERT(! svn_path_is_url(path));
@@ -82,18 +82,18 @@ print_update_summary(apr_array_header_t 
 
       /* Convert to an absolute path if it's not already. */
       if (! svn_dirent_is_absolute(path))
-        SVN_ERR(svn_dirent_get_absolute(&path, path, iter_pool));
+        SVN_ERR(svn_dirent_get_absolute(&path, path, iterpool));
       path = svn_dirent_local_style(svn_dirent_skip_ancestor(path_prefix,
-                                                             path), iter_pool);
+                                                             path), iterpool);
 
       /* Print an update summary for this target, removing the current
          working directory prefix from PATH (if PATH is at or under
          $CWD), and converting the path to local style for display. */
-      SVN_ERR(svn_cmdline_printf(iter_pool, _("  Updated '%s' to r%ld.\n"),
+      SVN_ERR(svn_cmdline_printf(iterpool, _("  Updated '%s' to r%ld.\n"),
                                  path, rev));
     }
 
-  svn_pool_destroy(iter_pool);
+  svn_pool_destroy(iterpool);
   return SVN_NO_ERROR;
 }
--- subversion/trunk/subversion/libsvn_client/externals.c (original)
+++ subversion/trunk/subversion/libsvn_client/externals.c Mon May  2 19:23:51 2011
@@ -77,7 +77,7 @@ struct handle_external_item_change_baton
 
   /* A scratchwork pool -- do not put anything in here that needs to
      outlive the hash diffing callback! */
-  apr_pool_t *iter_pool;
+  apr_pool_t *iterpool;
 };
 
 
@@ -691,7 +691,7 @@ handle_external_item_change(const void *
   svn_wc_external_item2_t *old_item, *new_item;
   const char *local_abspath = svn_dirent_join(ib->parent_dir_abspath,
                                               (const char *) key,
-                                              ib->iter_pool);
+                                              ib->iterpool);
 
   svn_ra_session_t *ra_session;
   svn_node_kind_t kind;
@@ -759,14 +759,14 @@ handle_external_item_change(const void *
                                                new_item->url, NULL,
                                                &(new_item->peg_revision),
                                                &(new_item->revision), ib->ctx,
-                                               ib->iter_pool));
+                                               ib->iterpool));
 
       SVN_ERR(svn_ra_get_uuid2(ra_session, &ra_cache.repos_uuid,
-                               ib->iter_pool));
+                               ib->iterpool));
       SVN_ERR(svn_ra_get_repos_root2(ra_session, &ra_cache.repos_root_url,
-                                     ib->iter_pool));
+                                     ib->iterpool));
       SVN_ERR(svn_ra_check_path(ra_session, "", ra_cache.ra_revnum, &kind,
-                                ib->iter_pool));
+                                ib->iterpool));
 
       if (svn_node_none == kind)
         return svn_error_createf(SVN_ERR_RA_ILLEGAL_URL, NULL,
@@ -798,15 +798,15 @@ handle_external_item_change(const void *
         (*ib->ctx->notify_func2)
           (ib->ctx->notify_baton2,
            svn_wc_create_notify(local_abspath, svn_wc_notify_update_external,
-                                ib->iter_pool), ib->iter_pool);
+                                ib->iterpool), ib->iterpool);
 
       switch (*ra_cache.kind_p)
         {
         case svn_node_dir:
           /* The target dir might have multiple components.  Guarantee
              the path leading down to the last component. */
-          parent_abspath = svn_dirent_dirname(local_abspath, ib->iter_pool);
-          SVN_ERR(svn_io_make_dir_recursively(parent_abspath, ib->iter_pool));
+          parent_abspath = svn_dirent_dirname(local_abspath, ib->iterpool);
+          SVN_ERR(svn_io_make_dir_recursively(parent_abspath, ib->iterpool));
 
           /* If we were handling renames the fancy way, then before
              checking out a new subdir here, we would somehow learn if
@@ -827,7 +827,7 @@ handle_external_item_change(const void *
                                        &(new_item->revision),
                                        TRUE, FALSE, svn_depth_infinity,
                                        ib->native_eol,
-                                       ib->ctx, ib->iter_pool));
+                                       ib->ctx, ib->iterpool));
           else
             SVN_ERR(svn_client__checkout_internal
                     (NULL, new_item->url, local_abspath,
@@ -835,7 +835,7 @@ handle_external_item_change(const void *
                      &ra_cache,
                      SVN_DEPTH_INFINITY_OR_FILES(TRUE),
                      FALSE, FALSE, TRUE, ib->timestamp_sleep, ib->ctx,
-                     ib->iter_pool));
+                     ib->iterpool));
           break;
         case svn_node_file:
           if (ib->is_export)
@@ -846,7 +846,7 @@ handle_external_item_change(const void *
                                        &(new_item->revision),
                                        FALSE, TRUE, svn_depth_infinity,
                                        ib->native_eol,
-                                       ib->ctx, ib->iter_pool));
+                                       ib->ctx, ib->iterpool));
           else
             SVN_ERR(switch_file_external(local_abspath,
                                          new_item->url,
@@ -857,7 +857,7 @@ handle_external_item_change(const void *
                                          ra_cache.ra_revnum,
                                          ra_cache.repos_root_url,
                                          ib->timestamp_sleep, ib->ctx,
-                                         ib->iter_pool));
+                                         ib->iterpool));
           break;
         default:
           SVN_ERR_MALFUNCTION();
@@ -873,14 +873,14 @@ handle_external_item_change(const void *
       svn_boolean_t lock_existed;
 
       SVN_ERR(svn_wc_locked2(&lock_existed, NULL, ib->ctx->wc_ctx,
-                             local_abspath, ib->iter_pool));
+                             local_abspath, ib->iterpool));
 
       if (! lock_existed)
         {
           SVN_ERR(svn_wc__acquire_write_lock(NULL, ib->ctx->wc_ctx,
                                              local_abspath, FALSE,
-                                             ib->iter_pool,
-                                             ib->iter_pool));
+                                             ib->iterpool,
+                                             ib->iterpool));
         }
 
       /* We don't use relegate_dir_external() here, because we know that
@@ -890,20 +890,20 @@ handle_external_item_change(const void *
       err = svn_wc_remove_from_revision_control2(
                         ib->ctx->wc_ctx, local_abspath, TRUE, FALSE,
                         ib->ctx->cancel_func, ib->ctx->cancel_baton,
-                        ib->iter_pool);
+                        ib->iterpool);
 
       if (ib->ctx->notify_func2)
         {
           svn_wc_notify_t *notify =
               svn_wc_create_notify(local_abspath,
                                    svn_wc_notify_update_external_removed,
-                                   ib->iter_pool);
+                                   ib->iterpool);
 
           notify->kind = svn_node_dir;
           notify->err = err;
 
           (ib->ctx->notify_func2)(ib->ctx->notify_baton2,
-                                  notify, ib->iter_pool);
+                                  notify, ib->iterpool);
         }
 
       if (err && err->apr_err == SVN_ERR_WC_LEFT_LOCAL_MOD)
@@ -918,7 +918,7 @@ handle_external_item_change(const void *
         {
           svn_error_t *err2 = svn_wc__release_write_lock(ib->ctx->wc_ctx,
                                                          local_abspath,
-                                                         ib->iter_pool);
+                                                         ib->iterpool);
 
           if (err2 && err2->apr_err == SVN_ERR_WC_NOT_LOCKED)
             {
@@ -942,9 +942,9 @@ handle_external_item_change(const void *
 
           nt = svn_wc_create_notify(local_abspath,
                                     svn_wc_notify_update_external,
-                                    ib->iter_pool);
+                                    ib->iterpool);
 
-          ib->ctx->notify_func2(ib->ctx->notify_baton2, nt,ib->iter_pool);
+          ib->ctx->notify_func2(ib->ctx->notify_baton2, nt,ib->iterpool);
         }
 
       /* Either the URL changed, or the exact same item is present in
@@ -959,7 +959,7 @@ handle_external_item_change(const void *
                                       &(new_item->revision),
                                       &(new_item->peg_revision),
                                       ib->timestamp_sleep, ib->ctx,
-                                      ib->iter_pool));
+                                      ib->iterpool));
           break;
         case svn_node_file:
           SVN_ERR(switch_file_external(local_abspath,
@@ -971,7 +971,7 @@ handle_external_item_change(const void *
                                        ra_cache.ra_revnum,
                                        ra_cache.repos_root_url,
                                        ib->timestamp_sleep, ib->ctx,
-                                       ib->iter_pool));
+                                       ib->iterpool));
           break;
         default:
           SVN_ERR_MALFUNCTION();
@@ -979,9 +979,9 @@ handle_external_item_change(const void *
         }
     }
 
   /* Clear ib->iter_pool -- we only use it for scratchwork (and this will
      close any RA sessions still open in this pool). */
-  svn_pool_clear(ib->iter_pool);
+  svn_pool_clear(ib->iterpool);
 
   return SVN_NO_ERROR;
 }
@@ -1000,14 +1000,14 @@ handle_external_item_change_wrapper(cons
       if (ib->ctx->notify_func2)
         {
           const char *local_abspath = svn_dirent_join(ib->parent_dir_abspath,
-                                                      key, ib->iter_pool);
+                                                      key, ib->iterpool);
           svn_wc_notify_t *notifier =
           svn_wc_create_notify(local_abspath,
                                svn_wc_notify_failed_external,
-                               ib->iter_pool);
+                               ib->iterpool);
           notifier->err = err;
           ib->ctx->notify_func2(ib->ctx->notify_baton2, notifier,
-                                ib->iter_pool);
+                                ib->iterpool);
         }
       svn_error_clear(err);
       return SVN_NO_ERROR;
@@ -1153,7 +1153,7 @@ handle_externals_desc_change(const void 
   ib.delete_only       = cb->delete_only;
   ib.timestamp_sleep   = cb->timestamp_sleep;
   ib.pool              = cb->pool;
-  ib.iter_pool         = svn_pool_create(cb->pool);
+  ib.iterpool         = svn_pool_create(cb->pool);
   ib.parent_dir_abspath = local_abspath;
 
   if (!cb->from_url)
@@ -1212,7 +1212,7 @@ handle_externals_desc_change(const void 
 
   /* Now destroy the subpool we pass to the hash differ.  This will
      close any remaining RA sessions used by the hash diff callback. */
-  svn_pool_destroy(ib.iter_pool);
+  svn_pool_destroy(ib.iterpool);
 
   return SVN_NO_ERROR;
 }
@@ -979,9 +979,9 @@ handle_external_item_change(const void *
     }
 
-  /* Clear ib->iter_pool -- we only use it for scratchwork (and this will
+  /* Clear ib->iterpool -- we only use it for scratchwork (and this will
      close any RA sessions still open in this pool). */

Modified: subversion/trunk/subversion/libsvn_repos/rev_hunt.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_repos/rev_hunt.c?rev=1098756&r1=1098755&r2=1098756&view=diff
==============================================================================